1.0.0 API documentation: GLM_GTX_texture

| 1.0.0 API documentation

Functions
GLM_GTX_texture
Experimental extensions

## Functions
template<length_t L, typename T , qualifier Q>
T | levels (vec< L, T, Q > const &Extent)
| Compute the number of mipmaps levels necessary to create a mipmap complete texture. More...

## Detailed Description

Include <glm/gtx/texture.hpp> to use the features of this extension.

Wrapping mode of texture coordinates.

## Function Documentation

## ◆ levels()

T glm::levels | ( | vec< L, T, Q > const & | Extent | ) |

Compute the number of mipmaps levels necessary to create a mipmap complete texture.

Parameters

  Extent | Extent of the texture base level mipmap

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point or signed integer scalar types
  Q | Value from qualifier enum